@@ -3,14 +3,12 @@
 #' @export
 summary.bain <- function(object, ci = .95, ...){
   # Fix this in bain; make sure that it always returns a matrix, even if
-  # posterior is only one number
-  if(class(object$posterior) == "numeric") object$posterior <- as.matrix(object$posterior)
-  object$n <- as.vector(object$n)
+  # posterior is only one numberfor
+  #if(class(object$posterior) == "numeric") object$posterior <- as.matrix(object$posterior)
+  #object$n <- as.vector(object$n)
   N <- object$n
-  if(!is.null(object$call[["group_parameters"]])){
-    if(length(object$n) > 1 & object$call$group_parameters > 1){
-      N <- rep(object$n, each = object$call$group_parameters)
-    }
+  if (length(object$n) > 1 & object$group_parameters > 1) {
+    N <- rep(object$n, each = object$group_parameters)
   }
   if(length(N) != length(object$estimates)){
     N <- c(N, rep(sum(object$n), length(object$estimates)-length(N)))
